@@ -40,11 +40,13 @@ is" without express or implied warranty.
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdarg.h>
+#include <signal.h>
 
 #include "X.h"
 #include "Xproto.h"
 #include "screenint.h"
 #include "input.h"
+#include "inputstr.h"
 #include "misc.h"
 #include "scrnintstr.h"
 #include "windowstr.h"
@@ -52,6 +54,7 @@ is" without express or implied warranty.
 #include "mi.h"
 #include <X11/fonts/fontstruct.h>
 #include "dixfontstr.h"
+#include "dixstruct.h"
 
 #include "Agent.h"
 #include "Display.h"
@@ -72,6 +75,7 @@ is" without express or implied warranty.
 #include "Error.h"
 #include "Keystroke.h"
 #include "Atoms.h"
+#include "Client.h"
 
 #include <nx/NX.h>
 #include "compext/Compext.h"
@@ -96,15 +100,6 @@ extern int (*ProcVector[256])(ClientPtr);
  */
 extern int fbGCPrivateIndex;
 
-#ifdef DPMSExtension
-/*
- * Stubs for the DPMS extension.
- */
-void DPMSSet(int level);
-int DPMSGet(int *level);
-Bool DPMSSupported(void);
-#endif
-
 /*
  * Our error logging function.
  */
@@ -137,6 +132,8 @@ extern void nxagentSetSelectionCallback(CallbackListPtr *callbacks, void *data,
                                    void *args);
 #endif
 
+OsTimerPtr nxagentTimeoutTimer = NULL;
+
 extern const char *nxagentProgName;
 
 void ddxInitGlobals(void)
@@ -391,9 +388,13 @@ FIXME: These variables, if not removed at all because have probably
   nxagentInitKeystrokes(False);
 
 #ifdef NXAGENT_CLIPBOARD
+  /* FIXME: we need to call DeleteCallback at shutdown, but where? */
   AddCallback(&SelectionCallback, nxagentSetSelectionCallback, NULL);
 #endif
 
+  /* FIXME: we need to call DeleteCallback at shutdown, but where? */
+  AddCallback(&ClientStateCallback, nxagentClientStateCallback, NULL);
+
   nxagentInitAtoms();
 }
 
@@ -476,6 +477,96 @@ void ddxBeforeReset(void)
 {
 }
 
+CARD32 nxagentTimeoutCallback(OsTimerPtr timer, CARD32 now, void *arg)
+{
+  CARD32 idle = now - lastDeviceEventTime.milliseconds;
+
+  #ifdef TEST
+  fprintf(stderr, "%s: called, idle [%d] timeout [%d]\n", __func__, idle, nxagentOption(Timeout) * MILLI_PER_SECOND);
+  #endif
+
+  /* Set the time to exactly match the remaining time until timeout */
+  if (idle < nxagentOption(Timeout) * MILLI_PER_SECOND)
+  {
+    return nxagentOption(Timeout) * MILLI_PER_SECOND - idle;
+  }
+
+   /*
+   * The lastDeviceEventTime is updated every time a device event is
+   * received, and it is used by WaitForSomething() to know when the
+   * SaveScreens() function should be called. This solution doesn't
+   * take care of a pointer button not being released, so we have to
+   * handle this case by ourselves.
+   */
+
+/*
+FIXME: Do we need to check the key grab if the
+       autorepeat feature is disabled?
+*/
+  if (inputInfo.pointer -> button -> buttonsDown > 0)
+  {
+    #ifdef TEST
+    fprintf(stderr, "%s: Prolonging timeout - there is a pointer button down.\n", __func__);
+    #endif
+
+    /* wait 10s more */
+    return 10 * MILLI_PER_SECOND;
+  }
+
+  if (nxagentSessionState == SESSION_UP )
+  {
+    if (nxagentClients == 0)
+    {
+      fprintf(stderr, "Info: Auto-terminating session with no client running.\n");
+      raise(SIGTERM);
+    }
+    else if (nxagentOption(Persistent) == 0)
+    {
+      fprintf(stderr, "Info: Auto-terminating session with persistence not allowed.\n");
+      raise(SIGTERM);
+    }
+    else
+    {
+      fprintf(stderr, "Info: Auto-suspending session with %d clients running.\n",
+                  nxagentClients);
+      raise(SIGHUP);
+    }
+  }
+
+  /*
+   * we do not need the timer anymore, so do not set a new time. The
+   * signals above will either terminate or suspend the session. At
+   * resume we will re-init the timer.
+   */
+  return 0;
+}
+
+void nxagentSetTimeoutTimer(unsigned int millis)
+{
+  if (nxagentOption(Timeout) > 0)
+  {
+    if (millis == 0)
+    {
+      millis = nxagentOption(Timeout) * MILLI_PER_SECOND;
+    }
+
+    #ifdef TEST
+    fprintf(stderr, "%s: Setting auto-disconnect timeout to [%dms]\n", __func__, millis);
+    #endif
+    nxagentTimeoutTimer = TimerSet(nxagentTimeoutTimer, 0, millis, nxagentTimeoutCallback, NULL);
+  }
+}
+
+void nxagentFreeTimeoutTimer(void)
+{
+  #ifdef TEST
+  fprintf(stderr, "%s: freeing timeout timer\n", __func__);
+  #endif
+  TimerFree(nxagentTimeoutTimer);
+  nxagentTimeoutTimer = NULL;
+}
+
+
 void OsVendorInit(void)
 {
   return;
@@ -531,19 +622,3 @@ static void nxagentGrabServerCallback(CallbackListPtr *callbacks, void *data,
     nxagentGrabServerInfo.client = grab->client;
     nxagentGrabServerInfo.grabstate = grab->grabstate;
 }
-
-#ifdef DPMSExtension
-void DPMSSet(int level)
-{
-}
-
-int DPMSGet(int *level)
-{
-  return -1;
-}
-
-Bool DPMSSupported(void)
-{
-  return 0;
-}
-#endif
