@@ -117,6 +117,7 @@ Equipment Corporation.
 
 #include "Atoms.h"
 #include "Splash.h"
+#include "Xdmcp.h"
 #include "Client.h"
 #include "Clipboard.h"
 #include "Reconnect.h"
@@ -125,6 +126,8 @@ Equipment Corporation.
 #include <nx/Shadow.h>
 #include "Handlers.h"
 #include "Keyboard.h"
+#include "Init.h"
+#include "Utils.h"
 
 const int nxagentMaxFontNames = 10000;
 
@@ -139,12 +142,6 @@ void nxagentWaitDisplay(void);
 
 void nxagentListRemoteFonts(const char *, int);
 
-/*
- * Timeouts based on screen saver time.
- */
-
-int nxagentAutoDisconnectTimeout = 0;
-
 #include "Xatom.h"
 
 /*
@@ -166,9 +163,7 @@ int nxagentAutoDisconnectTimeout = 0;
 #include "unistd.h"
 #endif
 
-#ifdef TEST
 #include "Literals.h"
-#endif
 
 #ifdef VIEWPORT_FRAME
 
@@ -312,6 +307,9 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
 
     if (!(dispatchException & DE_TERMINATE))
         dispatchException = 0;
+
+    /* Init TimeoutTimer if requested */
+    nxagentSetTimeoutTimer(0);
 #endif /* NXAGENT_SERVER */
 
     while (!dispatchException)
@@ -332,7 +330,7 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
 
         clientReady[0] = 0;
 
-        if (nxagentSplashWindow != None || (nxagentOption(Xdmcp) == 1 && nxagentXdmcpUp == 0))
+        if (nxagentHaveSplashWindow() || (nxagentOption(Xdmcp) == 1 && nxagentXdmcpUp == 0))
         {
           #ifdef TEST
           fprintf(stderr, "******Dispatch: Requesting a timeout of [%d] Ms.\n",
@@ -348,7 +346,7 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
                     (nxagentOption(Xdmcp) == 0 || nxagentXdmcpUp == 1))
         {
           #ifdef NX_DEBUG_INPUT
-          fprintf(stderr, "Session: Session started at '%s' timestamp [%lu].\n",
+          fprintf(stderr, "Session: Session started at '%s' timestamp [%u].\n",
                       GetTimeAsString(), GetTimeInMillis());
           #else
           fprintf(stderr, "Session: Session started at '%s'.\n",
@@ -420,7 +418,7 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
 	    isItTimeToYield = FALSE;
  
 #ifdef NXAGENT_SERVER
-            nxagentRequestingClient = client;
+	    nxagentRequestingClient = client;
 #endif
 	    start_tick = SmartScheduleTime;
 	    while (!isItTimeToYield)
@@ -547,6 +545,8 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
 #endif
 
 #ifdef NXAGENT_SERVER
+    nxagentFreeTimeoutTimer();
+
     /* FIXME: maybe move the code up to the KillAllClients() call to ddxBeforeReset? */
     if ((dispatchException & DE_RESET) && 
             (serverGeneration > nxagentMaxAllowedResets))
@@ -580,8 +580,13 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
       NXShadowDestroy();
     }
     saveAgentState("TERMINATED");
+
+    nxagentFreeAtomMap();
+    nxagentFreeFontData();
 #endif /* NXAGENT_SERVER */
 
+    nxagentFreeAtomMap();
+
     KillAllClients();
     free(clientReady);
     dispatchException &= ~DE_RESET;
@@ -744,7 +749,7 @@ ProcConvertSelection(register ClientPtr client)
 #ifdef NXAGENT_SERVER
 	    (CurrentSelections[i].window != None) && (CurrentSelections[i].client != NullClient)
 #else
-	    (CurrentSelections[i].window != None))
+	    (CurrentSelections[i].window != None)
 #endif
 #ifdef XCSECURITY
 	    && (!client->CheckAccess ||
@@ -799,12 +804,12 @@ ProcOpenFont(register ClientPtr client)
 
 #ifdef NXAGENT_SERVER
     char fontReq[256];
-    memcpy(fontReq,(char *)&stuff[1],(stuff->nbytes<256)?stuff->nbytes:255);
-    fontReq[stuff->nbytes]=0;
-    if (strchr(fontReq,'*') || strchr(fontReq,'?'))
+    memcpy(fontReq,(char *)&stuff[1], (stuff->nbytes < 256) ? stuff->nbytes : 255);
+    fontReq[stuff->nbytes] = '\0';
+    if (strchr(fontReq, '*') || strchr(fontReq, '?'))
     {
 #ifdef NXAGENT_FONTMATCH_DEBUG
-       fprintf(stderr, "Dispatch: ProcOpenFont try to find a common font with font pattern=%s\n",fontReq);
+       fprintf(stderr, "%s: try to find a common font with font pattern [%s]\n", __func__, fontReq);
 #endif
        nxagentListRemoteFonts(fontReq, nxagentMaxFontNames);
        err = nxOpenFont(client, stuff->fid, (Mask) 0,
@@ -836,10 +841,9 @@ ProcCloseFont(register ClientPtr client)
         #ifdef NXAGENT_SERVER
 
         /*
-         * When a client closes a font the resource
-         * should not be lost if the reference counter
-         * is not 0, otherwise the server will not be
-         * able to find this font looping through the
+         * When a client closes a font the resource should not be lost
+         * if the reference counter is not 0, otherwise the server
+         * will not be able to find this font looping through the
          * resources.
          */
 
@@ -848,7 +852,7 @@ ProcCloseFont(register ClientPtr client)
           if (nxagentFindClientResource(serverClient -> index, RT_NX_FONT, pFont) == 0)
           {
             #ifdef TEST
-            fprintf(stderr, "ProcCloseFont: Switching resource for font at [%p].\n",
+            fprintf(stderr, "%s: Switching resource for font at [%p].\n", __func__,
                         (void *) pFont);
             #endif
 
@@ -860,8 +864,8 @@ ProcCloseFont(register ClientPtr client)
           #ifdef TEST
           else
           {
-            fprintf(stderr, "ProcCloseFont: Found duplicated font at [%p], "
-                        "resource switching skipped.\n", (void *) pFont);
+            fprintf(stderr, "%s: Found duplicated font at [%p], "
+                        "resource switching skipped.\n", __func__, (void *) pFont);
           }
           #endif
         }
@@ -888,11 +892,11 @@ ProcListFonts(register ClientPtr client)
 
 #ifdef NXAGENT_SERVER
     char tmp[256];
-    memcpy(tmp,(unsigned char *) &stuff[1],(stuff->nbytes<256)?stuff->nbytes:255);
-    tmp[stuff->nbytes]=0;
+    memcpy(tmp, (unsigned char *) &stuff[1], (stuff->nbytes < 256) ? stuff->nbytes : 255);
+    tmp[stuff->nbytes] = '\0';
 
 #ifdef NXAGENT_FONTMATCH_DEBUG
-    fprintf(stderr, "Dispatch: ListFont request with pattern %s max_names=%d\n",tmp,stuff->maxNames);
+    fprintf(stderr, "%s: ListFont request with pattern [%s] max_names [%d]\n", __func__, tmp, stuff->maxNames);
 #endif
     nxagentListRemoteFonts(tmp, stuff -> maxNames < nxagentMaxFontNames ? nxagentMaxFontNames : stuff->maxNames);
 #endif
@@ -910,12 +914,12 @@ ProcListFontsWithInfo(register ClientPtr client)
 
 #ifdef NXAGENT_SERVER
     char tmp[256];
-    memcpy(tmp,(unsigned char *) &stuff[1],(stuff->nbytes<256)?stuff->nbytes:255);
-    tmp[stuff->nbytes]=0;
+    memcpy(tmp, (unsigned char *) &stuff[1], (stuff->nbytes < 256) ? stuff->nbytes : 255);
+    tmp[stuff->nbytes] = '\0';
 #ifdef NXAGENT_FONTMATCH_DEBUG
-    fprintf(stderr, "Dispatch: ListFont with info request with pattern %s max_names=%d\n",tmp,stuff->maxNames);
+    fprintf(stderr, "%s: ListFont with info request with pattern [%s] max_names [%d]\n", __func__, tmp, stuff->maxNames);
 #endif
-    nxagentListRemoteFonts(tmp, stuff -> maxNames < nxagentMaxFontNames ? nxagentMaxFontNames :stuff->maxNames);
+    nxagentListRemoteFonts(tmp, stuff -> maxNames < nxagentMaxFontNames ? nxagentMaxFontNames : stuff->maxNames);
 #endif
 
     return StartListFontsWithInfo(client, stuff->nbytes,
@@ -937,11 +941,10 @@ ProcFreePixmap(register ClientPtr client)
         #ifdef NXAGENT_SERVER
 
         /*
-         * When a client releases a pixmap the resource
-         * should not be lost if the reference counter
-         * is not 0, otherwise the server will not be
-         * able to find this pixmap looping through the
-         * resources.
+         * When a client releases a pixmap the resource should not be
+         * lost if the reference counter is not 0, otherwise the
+         * server will not be able to find this pixmap looping through
+         * the resources.
          */
 
         if (pMap -> refcnt > 0)
@@ -960,8 +963,8 @@ ProcFreePixmap(register ClientPtr client)
           #ifdef TEST
           else
           {
-            fprintf(stderr, "ProcFreePixmap: Found duplicated pixmap at [%p], "
-                        "resource switching skipped.\n", (void *) pMap);
+            fprintf(stderr, "%s: Found duplicated pixmap at [%p], "
+                        "resource switching skipped.\n", __func__, (void *) pMap);
           }
           #endif
         }
@@ -978,155 +981,6 @@ ProcFreePixmap(register ClientPtr client)
     }
 }
 
-
-int
-ProcSetScreenSaver (register ClientPtr client)
-{
-    int blankingOption, exposureOption;
-    REQUEST(xSetScreenSaverReq);
-
-    REQUEST_SIZE_MATCH(xSetScreenSaverReq);
-    blankingOption = stuff->preferBlank;
-    if ((blankingOption != DontPreferBlanking) &&
-        (blankingOption != PreferBlanking) &&
-        (blankingOption != DefaultBlanking))
-    {
-	client->errorValue = blankingOption;
-        return BadValue;
-    }
-    exposureOption = stuff->allowExpose;
-    if ((exposureOption != DontAllowExposures) &&
-        (exposureOption != AllowExposures) &&
-        (exposureOption != DefaultExposures))
-    {
-	client->errorValue = exposureOption;
-        return BadValue;
-    }
-    if (stuff->timeout < -1)
-    {
-	client->errorValue = stuff->timeout;
-        return BadValue;
-    }
-    if (stuff->interval < -1)
-    {
-	client->errorValue = stuff->interval;
-        return BadValue;
-    }
-
-#ifdef NXAGENT_SERVER
-    /*
-     * The NX agent uses the screen saver procedure
-     * to monitor the user activities and launch its
-     * handlers (like timeout feature), so we can't
-     * always allow the clients to change our values.
-     */
-
-    #ifdef TEST
-    fprintf(stderr, "ProcSetScreenSaver: Called with timeout [%d] interval [%d] Blanking [%d] Exposure [%d].\n",
-                stuff -> timeout, stuff -> interval, blankingOption, exposureOption);
-    #endif
-
-    if (nxagentOption(Timeout) == 0)
-    {
-#endif
-      if (blankingOption == DefaultBlanking)
-      {
-	ScreenSaverBlanking = defaultScreenSaverBlanking;
-      }
-      else
-      {
-	ScreenSaverBlanking = blankingOption; 
-      }
-
-      if (exposureOption == DefaultExposures)
-      {
-	ScreenSaverAllowExposures = defaultScreenSaverAllowExposures;
-      }
-      else
-      {
-        ScreenSaverAllowExposures = exposureOption;
-      }
-
-      if (stuff->timeout >= 0)
-      {
-        ScreenSaverTime = stuff->timeout * MILLI_PER_SECOND;
-      }
-      else
-      {
-        ScreenSaverTime = defaultScreenSaverTime;
-      }
-
-      if (stuff->interval >= 0)
-      {
-        ScreenSaverInterval = stuff->interval * MILLI_PER_SECOND;
-      }
-      else
-      {
-        ScreenSaverInterval = defaultScreenSaverInterval;
-      }
-
-      SetScreenSaverTimer();
-#ifdef NXAGENT_SERVER
-    }
-
-    #ifdef TEST
-
-    else
-    {
-      fprintf(stderr, "ProcSetScreenSaver: Keeping auto-disconnect timeout set to [%d] seconds.\n",
-                  nxagentOption(Timeout));
-    }
-
-    #endif
-#endif
-    return (client->noClientException);
-}
-
-
-int ProcForceScreenSaver(register ClientPtr client)
-{
-    REQUEST(xForceScreenSaverReq);
-
-    REQUEST_SIZE_MATCH(xForceScreenSaverReq);
-
-    if ((stuff->mode != ScreenSaverReset) &&
-	(stuff->mode != ScreenSaverActive))
-    {
-	client->errorValue = stuff->mode;
-        return BadValue;
-    }
-
-#ifdef NXAGENT_SERVER
-    /*
-     * The NX agent uses the screen saver procedure
-     * to monitor the user activities and launch its
-     * handlers (like timeout feature), so we can't
-     * always allow the clients to force the screen
-     * saver handler execution.
-     */
-
-    if (nxagentOption(Timeout) == 0)
-    {
-#endif
-      SaveScreens(SCREEN_SAVER_FORCER, (int)stuff->mode);
-#ifdef NXAGENT_SERVER
-    }
-
-    #ifdef TEST
-
-    else
-    {
-      fprintf(stderr, "ProcForceScreenSaver: Ignoring the client request with mode [%d].\n",
-                  stuff -> mode);
-    }
-
-    #endif
-#endif
-
-    return client->noClientException;
-}
-
-
 /**********************
  * CloseDownClient
  *
@@ -1137,51 +991,18 @@ int ProcForceScreenSaver(register ClientPtr client)
 void
 CloseDownClient(register ClientPtr client)
 {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: [%d]\n", __func__, client->clientState);
+    #endif
+
 #ifdef NXAGENT_SERVER
     /*
-     * There must be a better way to hook a
-     * call-back function to be called any
-     * time a client is going to be closed.
-     */
-
-    nxagentClearClipboard(client, NULL);
-
-    /*
-     * Need to reset the karma counter and
-     * get rid of the pending sync replies.
+     * Need to reset the karma counter and get rid of the pending sync
+     * replies.
      */
 
     nxagentWakeupByReset(client);
-
-    /*
-     * Check if the client
-     * is a shadow nxagent.
-     */
-
-    nxagentCheckIfShadowAgent(client);
 #endif
 
     xorg_CloseDownClient(client);
 }
-
-/* FIXME: Instead of having a own function use the provided Callback
-   mechanism */
-int
-InitClientPrivates(ClientPtr client)
-{
-    int ret = xorg_InitClientPrivates(client);
-
-#ifdef NXAGENT_SERVER
-    if (ret == 1)
-    {
-
-      /*
-       * Initialize the private members.
-       */
-
-      nxagentInitClientPrivates(client);
-    }
-#endif
-
-    return ret;
-}
